Jp2kDecodeResult class final

Result of decoding one JPEG2000 codestream. pixels is interleaved, tightly packed, width * height * num_components bytes — NULL on failure, in which case error is set instead (else NULL).

Every non-NULL result (whether it succeeded or carries an error) must be passed to jp2k_free_result exactly once.

Inheritance
Implemented types
Available extensions

Constructors

Jp2kDecodeResult()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
error Pointer<Char>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
num_components int
getter/setter pair
pixels Pointer<Uint8>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

$allocate(Allocator $allocator, {required int width, required int height, required int num_components, required Pointer<Uint8> pixels, required Pointer<Char> error}) Pointer<Jp2kDecodeResult>